/*
 * ble_whts.h
 *
 *  Created on: Dec 16, 2015
 *      Author: C9917732
 */

#ifndef BLE_WHTS_H__
#define BLE_WHTS_H__

#include <stdint.h>
#include "ble.h"
#include "ble_srv_common.h"

#define BLE_UUID_WHTS_SERVICE 0x0001     /**< The UUID of the custom service          */
#define BLE_UUID_WHTS_SENSOR  0x0002     /**< The UUID of the sensor characteristic   */
#define BLE_UUID_WHTS_LED     0x0003     /**< The UUID of the LED ctrl characteristic */


/** @brief Water Heater Service event type */
typedef enum
{
    BLE_WHTS_EVT_NOTIFICATION_ENABLED,  /**< WHT value notification enabled event  */
    BLE_WHTS_EVT_NOTIFICATION_DISABLED, /**< WHT value notification disabled event */
} ble_whts_evt_type_t;

typedef struct
{
    ble_whts_evt_type_t evt_type;       /**< type of event */
} ble_whts_evt_t;

// Forward declaration of the ble_whts_t type
typedef struct ble_whts_s ble_whts_t;

/**@brief Water Heater Temperature Service event handler type. */
typedef void (*ble_whts_evt_handler_t) (ble_whts_t* p_whts, ble_whts_evt_t* p_evt);

/**@brief Water Heater Temperature Service init structure. This contains all options and data
 *        needed for initialization of the service. */
typedef struct
{
    ble_whts_evt_handler_t       evt_handler;         /**< Event handler to be called for whts. */

    ble_srv_cccd_security_mode_t whts_sensor_attr_md; /**< initial security lvl for sensor      */

} ble_whts_init_t;

/**@brief Water Heater Temperature Service structure. This contains various status information for
 *        the service. */
struct ble_whts_s
{
    ble_whts_evt_handler_t       evt_handler;    /**< Event handler to be called for whts.     */
    uint16_t                     service_handle; /**< Handle of whts provided by stack         */
    ble_gatts_char_handles_t     sensor_handle;  /**< handle for temp sensor measurement char. */
    uint8_t                      uuid_type;      /**< UUID type for water heater temp svc      */
    uint16_t                     conn_handle;    /**< Handle of the current connection (as provided by the BLE stack, is BLE_CONN_HANDLE_INVALID if not in a connection). */
};

/**@brief Function for initializing the Water Heater Temperature Service.
 *
 * @param[out]  p_whts      Water Heater Temperature Service structure. This structure will have to
 *                          be supplied by the application. It will be initialized by this function,
 *                          and will later be used to identify this particular service instance.
 * @param[in]   p_whts_init Information needed to initialize the service.
 *
 * @return      NRF_SUCCESS on successful initialization of service, otherwise an error code.
 */
uint32_t ble_whts_init(ble_whts_t* p_whts, const ble_whts_init_t* p_whts_init);




#endif
